package org.apache.commons.lang3.concurrent;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import java.util.Collections;
import java.util.Map;
import java.util.NoSuchElementException;
import java.util.Set;
import org.apache.commons.lang3.concurrent.BackgroundInitializer;
import org.apache.commons.lang3.concurrent.ConcurrentException;
import org.apache.commons.lang3.concurrent.MultiBackgroundInitializer;

public class MultiBackgroundInitializerResults {
  private final Map<String, BackgroundInitializer<?>> initializers;
  
  private final Map<String, Object> resultObjects;
  
  private final Map<String, ConcurrentException> exceptions;
  
  private MultiBackgroundInitializerResults(Map<String, BackgroundInitializer<?>> inits, Map<String, Object> results, Map<String, ConcurrentException> excepts) {
    this.initializers = inits;
    this.resultObjects = results;
    this.exceptions = excepts;
  }
  
  public BackgroundInitializer<?> getInitializer(String name) {
    return checkName(name);
  }
  
  public Object getResultObject(String name) {
    checkName(name);
    return this.resultObjects.get(name);
  }
  
  public boolean isException(String name) {
    checkName(name);
    return this.exceptions.containsKey(name);
  }
  
  public ConcurrentException getException(String name) {
    checkName(name);
    return this.exceptions.get(name);
  }
  
  public Set<String> initializerNames() {
    return Collections.unmodifiableSet(this.initializers.keySet());
  }
  
  public boolean isSuccessful() {
    return this.exceptions.isEmpty();
  }
  
  private BackgroundInitializer<?> checkName(String name) {
    BackgroundInitializer<?> init = this.initializers.get(name);
    if (init == null)
      throw new NoSuchElementException("No child initializer with name " + name); 
    return init;
  }
}
